==> haskell-repline-0.4.2.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-repline.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 repline
version:              0.4.2.0
visibility:           public
id:                   repline-0.4.2.0-AbdnKl4MT5R8rpoSYZ99OS
key:                  repline-0.4.2.0-AbdnKl4MT5R8rpoSYZ99OS
license:              MIT
copyright:            2014-2022 Stephen Diehl
maintainer:           stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/repline
synopsis:             Haskeline wrapper for GHCi-like REPL interfaces.
description:
    Haskeline wrapper for GHCi-like REPL interfaces. Composable with normal mtl transformers.

category:             User Interfaces
abi:                  7870f6317b3d6bb2f74d56b8b34df643
exposed:              True
exposed-modules:      System.Console.Repline
import-dirs:          /usr/lib/ghc-9.0.2/site-local/repline-0.4.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/repline-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-repline
hs-libraries:         HSrepline-0.4.2.0-AbdnKl4MT5R8rpoSYZ99OS
depends:
    base-4.15.1.0 containers-0.6.4.1 exceptions-0.10.4 haskeline-0.8.2
    mtl-2.2.2 process-1.6.13.2

haddock-interfaces:   /usr/share/doc/haskell-repline/html/repline.haddock
haddock-html:         /usr/share/doc/haskell-repline/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-repline-0.4.2.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-repline.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 repline
version:              0.4.2.0
visibility:           public
id:                   repline-0.4.2.0-8F4hfQj1tzA4brx66W1hS8
key:                  repline-0.4.2.0-8F4hfQj1tzA4brx66W1hS8
license:              MIT
copyright:            2014-2022 Stephen Diehl
maintainer:           stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/repline
synopsis:             Haskeline wrapper for GHCi-like REPL interfaces.
description:
    Haskeline wrapper for GHCi-like REPL interfaces. Composable with normal mtl transformers.

category:             User Interfaces
abi:                  6dbc813196649637696f55cee1baefb5
exposed:              True
exposed-modules:      System.Console.Repline
import-dirs:          /usr/lib/ghc-9.2.8/site-local/repline-0.4.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/repline-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-repline
hs-libraries:         HSrepline-0.4.2.0-8F4hfQj1tzA4brx66W1hS8
depends:
    base-4.16.4.0 containers-0.6.5.1 exceptions-0.10.4 haskeline-0.8.2
    mtl-2.2.2 process-1.6.16.0

haddock-interfaces:   /usr/share/doc/haskell-repline/html/repline.haddock
haddock-html:         /usr/share/doc/haskell-repline/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
